@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class RegexpTest : public QObject
     Q_OBJECT
 public:
     explicit RegexpTest(QObject *parent = nullptr);
-    ~RegexpTest() = default;
+    ~RegexpTest() override = default;
 private Q_SLOTS:
     void compareRegexp_data();
     void compareRegexp();
