@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "regexpeditorlineedittest.h"
 #include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
-#include <QTest>
-#include <QLineEdit>
 #include <QHBoxLayout>
+#include <QLineEdit>
+#include <QTest>
 
 RegexpEditorLineEditTest::RegexpEditorLineEditTest(QObject *parent)
     : QObject(parent)
@@ -18,10 +18,10 @@ RegexpEditorLineEditTest::RegexpEditorLineEditTest(QObject *parent)
 void RegexpEditorLineEditTest::shouldHaveDefaultValue()
 {
     KSieveUi::RegexpEditorLineEdit w;
-    auto *mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
+    auto mLineEdit = w.findChild<QLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(mLineEdit);
 
-    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 }
