@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SieveEditorGraphicalModeWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit SieveEditorGraphicalModeWidgetTest(QObject *parent = nullptr);
-    ~SieveEditorGraphicalModeWidgetTest() = default;
+    ~SieveEditorGraphicalModeWidgetTest() override = default;
 private Q_SLOTS:
     void shouldLoadScripts();
     void shouldLoadScripts_data();
