@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,13 +8,14 @@
 
 #include <QWidget>
 class QSpinBox;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectConvertParameterWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SelectConvertParameterWidget(QWidget *parent = nullptr);
-    ~SelectConvertParameterWidget();
+    ~SelectConvertParameterWidget() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QStringList &code, QString &error);
