@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,13 +7,14 @@
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
+#include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
-#include <QGridLayout>
 
 using namespace KSieveUi;
 SieveActionExtractText::SieveActionExtractText(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -23,15 +24,15 @@ SieveActionExtractText::SieveActionExtractText(SieveEditorGraphicalModeWidget *s
 
 QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *grid = new QGridLayout;
+    auto w = new QWidget(parent);
+    auto grid = new QGridLayout;
     grid->setContentsMargins({});
     w->setLayout(grid);
 
-    QLabel *lab = new QLabel(i18n("Number of characters:"));
+    auto lab = new QLabel(i18n("Number of characters:"));
     grid->addWidget(lab, 0, 0);
 
-    auto *nbCharacters = new QSpinBox;
+    auto nbCharacters = new QSpinBox;
     nbCharacters->setMinimum(1);
     nbCharacters->setMaximum(99999);
     nbCharacters->setObjectName(QStringLiteral("numberOfCharacters"));
@@ -41,7 +42,8 @@ QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Stored in variable name:"));
     grid->addWidget(lab, 1, 0);
 
-    auto *variableName = new QLineEdit;
+    auto variableName = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(variableName, w);
     connect(variableName, &QLineEdit::textChanged, this, &SieveActionExtractText::valueChanged);
     variableName->setObjectName(QStringLiteral("variablename"));
     grid->addWidget(variableName, 1, 1);
@@ -56,19 +58,19 @@ void SieveActionExtractText::setParamWidgetValue(QXmlStreamReader &element, QWid
 
         if (tagName == QLatin1String("tag")) {
             element.skipCurrentElement();
-            //TODO ?
+            // TODO ?
         } else if (tagName == QLatin1String("num")) {
-            auto *numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
+            auto numberOfCharacters = w->findChild<QSpinBox *>(QStringLiteral("numberOfCharacters"));
             numberOfCharacters->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("str")) {
-            auto *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            auto variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(element.readElementText());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
