@@ -1,12 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef SIEVEACTIONKEEP_H
 #define SIEVEACTIONKEEP_H
 #include "sieveaction.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionKeep : public SieveAction
 {
     Q_OBJECT
