@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,10 +8,12 @@
 
 #include <QVector>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveAction;
 class SieveEditorGraphicalModeWidget;
-namespace SieveActionList {
+namespace SieveActionList
+{
 Q_REQUIRED_RESULT QVector<KSieveUi::SieveAction *> actionList(KSieveUi::SieveEditorGraphicalModeWidget *graphicalModeWidget);
 }
 }
