@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,16 @@
 #ifndef SIEVEACTIONWIDGETLISTER_H
 #define SIEVEACTIONWIDGETLISTER_H
 
-#include <Libkdepim/KWidgetLister>
 #include "sieveglobalvariablewidget.h"
+#include <Libkdepim/KWidgetLister>
 class QPushButton;
 class QComboBox;
 class QGridLayout;
 class QToolButton;
 class QXmlStreamReader;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveAction;
 class SieveHelpButton;
 class SieveEditorGraphicalModeWidget;
@@ -24,7 +25,7 @@ class SieveActionWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveActionWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent);
-    ~SieveActionWidget();
+    ~SieveActionWidget() override;
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
     void generatedScript(QString &script, QStringList &required, bool onlyActions, bool inForEveryPartLoop);
@@ -81,6 +82,7 @@ Q_SIGNALS:
 protected:
     void clearWidget(QWidget *aWidget) override;
     QWidget *createWidget(QWidget *parent) override;
+
 private:
     void reconnectWidget(SieveActionWidget *w);
     void updateAddRemoveButton();
