@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionservermetadataexists.h"
-#include "editor/sieveeditorutil.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "editor/sieveeditorutil.h"
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
-#include <QHBoxLayout>
 #include "libksieve_debug.h"
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QXmlStreamReader>
 
@@ -22,15 +23,16 @@ SieveConditionServerMetaDataExists::SieveConditionServerMetaDataExists(SieveEdit
 
 QWidget *SieveConditionServerMetaDataExists::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLabel *lab = new QLabel(i18n("Annotation:"));
+    auto lab = new QLabel(i18n("Annotation:"));
     lay->addWidget(lab);
 
-    auto *value = new QLineEdit;
+    auto value = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(value, w);
     value->setObjectName(QStringLiteral("value"));
     connect(value, &QLineEdit::textChanged, this, &SieveConditionServerMetaDataExists::valueChanged);
     lay->addWidget(value);
@@ -72,11 +74,11 @@ void SieveConditionServerMetaDataExists::setParamWidgetValue(QXmlStreamReader &e
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            auto *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
+            auto value = w->findChild<QLineEdit *>(QStringLiteral("value"));
             value->setText(tagValue);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
