@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionsize.h"
-#include "widgets/selectsizewidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/selectsizewidget.h"
 #include <KLocalizedString>
 
-#include <QHBoxLayout>
-#include <QComboBox>
-#include <QXmlStreamReader>
 #include "libksieve_debug.h"
+#include <QComboBox>
+#include <QHBoxLayout>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
@@ -23,19 +23,19 @@ SieveConditionSize::SieveConditionSize(SieveEditorGraphicalModeWidget *sieveGrap
 
 QWidget *SieveConditionSize::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *combo = new QComboBox;
+    auto combo = new QComboBox;
     combo->setObjectName(QStringLiteral("combosize"));
     combo->addItem(i18n("under"), QStringLiteral(":under"));
     combo->addItem(i18n("over"), QStringLiteral(":over"));
     lay->addWidget(combo);
     connect(combo, QOverload<int>::of(&QComboBox::activated), this, &SieveConditionSize::valueChanged);
 
-    auto *sizeWidget = new SelectSizeWidget;
+    auto sizeWidget = new SelectSizeWidget;
     connect(sizeWidget, &SelectSizeWidget::valueChanged, this, &SieveConditionSize::valueChanged);
     sizeWidget->setObjectName(QStringLiteral("sizewidget"));
     lay->addWidget(sizeWidget);
@@ -53,7 +53,9 @@ QString SieveConditionSize::code(QWidget *w) const
 
 QString SieveConditionSize::help() const
 {
-    return i18n("The \"size\" test deals with the size of a message.  It takes either a tagged argument of \":over\" or \":under\", followed by a number representing the size of the message.");
+    return i18n(
+        "The \"size\" test deals with the size of a message.  It takes either a tagged argument of \":over\" or \":under\", followed by a number representing "
+        "the size of the message.");
 }
 
 void SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
@@ -63,7 +65,7 @@ void SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
-            auto *combo = w->findChild<QComboBox *>(QStringLiteral("combosize"));
+            auto combo = w->findChild<QComboBox *>(QStringLiteral("combosize"));
             const int index = combo->findData(AutoCreateScriptUtil::tagValue(tagValue));
             if (index != -1) {
                 combo->setCurrentIndex(index);
@@ -74,11 +76,11 @@ void SieveConditionSize::setParamWidgetValue(QXmlStreamReader &element, QWidget
                 numIdentifier = element.attributes().value(QLatin1String("quantifier")).toString();
             }
             const qlonglong tagValue = element.readElementText().toLongLong();
-            auto *sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
+            auto sizeWidget = w->findChild<SelectSizeWidget *>(QStringLiteral("sizewidget"));
             sizeWidget->setCode(tagValue, numIdentifier, name(), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
