@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,19 +11,21 @@
 class QComboBox;
 class QLineEdit;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectBodyTypeWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SelectBodyTypeWidget(QWidget *parent = nullptr);
-    ~SelectBodyTypeWidget();
+    ~SelectBodyTypeWidget() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &type, const QString &content, const QString &name, QString &error);
 
 Q_SIGNALS:
     void valueChanged();
+
 private:
     void slotBodyTypeChanged(int);
     void initialize();
