@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef SELECTDATEWIDGET_H
 #define SELECTDATEWIDGET_H
 
-#include <QWidget>
-#include <QSpinBox>
 #include "ksieveui_private_export.h"
+#include <QSpinBox>
+#include <QWidget>
 
 class QComboBox;
 class QLineEdit;
@@ -16,29 +16,16 @@ class QStackedWidget;
 class QSpinBox;
 class KDateComboBox;
 class KTimeComboBox;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveDateSpinBox;
 class KSIEVEUI_TESTS_EXPORT SelectDateWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum DateType {
-        Year = 0,
-        Month,
-        Day,
-        Date,
-        Julian,
-        Hour,
-        Minute,
-        Second,
-        Time,
-        Iso8601,
-        Std11,
-        Zone,
-        Weekday
-    };
+    enum DateType { Year = 0, Month, Day, Date, Julian, Hour, Minute, Second, Time, Iso8601, Std11, Zone, Weekday };
     explicit SelectDateWidget(QWidget *parent = nullptr);
-    ~SelectDateWidget();
+    ~SelectDateWidget() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &type, const QString &value);
