@@ -1,25 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "selectheadertypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include <Libkdepim/LineEditCatchReturnKey>
 #include <KLocalizedString>
-#include <QPushButton>
+#include <Libkdepim/LineEditCatchReturnKey>
+#include <QIcon>
 #include <QLineEdit>
 #include <QPointer>
-#include <QIcon>
+#include <QPushButton>
 
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QLabel>
+#include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
-#include <KConfigGroup>
-#include <QEvent>
-#include <QKeyEvent>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
@@ -30,9 +28,9 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Headers"));
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -40,7 +38,7 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SelectHeadersDialog::reject);
     okButton->setFocus();
 
-    auto *lay = new QVBoxLayout;
+    auto lay = new QVBoxLayout;
     lay->setObjectName(QStringLiteral("widgetlayout"));
     lay->setContentsMargins({});
     mainLayout->addLayout(lay);
@@ -48,17 +46,17 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
     mListWidget->setObjectName(QStringLiteral("listwidget"));
     lay->addWidget(mListWidget);
 
-    QLabel *lab = new QLabel(i18n("Add new header:"), this);
+    auto lab = new QLabel(i18n("Add new header:"), this);
     lab->setObjectName(QStringLiteral("label"));
     lay->addWidget(lab);
 
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
 
     mNewHeader = new QLineEdit(this);
     new KPIM::LineEditCatchReturnKey(mNewHeader, this);
     mNewHeader->setObjectName(QStringLiteral("newheader"));
     mNewHeader->setClearButtonEnabled(true);
-    //mNewHeader->setTrapReturnKey(true);
+    // mNewHeader->setTrapReturnKey(true);
     connect(mNewHeader, &QLineEdit::returnPressed, this, &SelectHeadersDialog::slotAddNewHeader);
     mNewHeader->setClearButtonEnabled(true);
 
@@ -143,7 +141,7 @@ void SelectHeadersWidget::addNewHeader(const QString &header)
         }
     }
 
-    auto *item = new QListWidgetItem(header, this);
+    auto item = new QListWidgetItem(header, this);
     item->setData(HeaderId, header);
     item->setCheckState(Qt::Checked);
     scrollToItem(item);
@@ -155,7 +153,7 @@ void SelectHeadersWidget::setListHeaders(const QMap<QString, QString> &lst, cons
     while (i.hasNext()) {
         i.next();
         if (!i.value().isEmpty()) {
-            auto *item = new QListWidgetItem(i.value(), this);
+            auto item = new QListWidgetItem(i.value(), this);
             item->setData(HeaderId, i.key());
             if (selectedHeaders.contains(i.key())) {
                 item->setCheckState(Qt::Checked);
@@ -166,7 +164,7 @@ void SelectHeadersWidget::setListHeaders(const QMap<QString, QString> &lst, cons
     }
     for (const QString &header : selectedHeaders) {
         if (!lst.contains(header)) {
-            auto *item = new QListWidgetItem(header, this);
+            auto item = new QListWidgetItem(header, this);
             item->setData(HeaderId, header);
             item->setCheckState(Qt::Checked);
         }
@@ -199,13 +197,9 @@ SelectHeaderTypeComboBox::SelectHeaderTypeComboBox(bool onlyEnvelopType, QWidget
 {
     setEditable(true);
     lineEdit()->setClearButtonEnabled(true);
-    //TODO add completion
+    // TODO add completion
     initialize(onlyEnvelopType);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    connect(this, QOverload<const QString &>::of(&SelectHeaderTypeComboBox::activated), this, &SelectHeaderTypeComboBox::slotSelectItem);
-#else
     connect(this, &SelectHeaderTypeComboBox::textActivated, this, &SelectHeaderTypeComboBox::slotSelectItem);
-#endif
     connect(this, &SelectHeaderTypeComboBox::editTextChanged, this, &SelectHeaderTypeComboBox::valueChanged);
     connect(this, QOverload<int>::of(&SelectHeaderTypeComboBox::activated), this, &SelectHeaderTypeComboBox::valueChanged);
 }
@@ -276,7 +270,7 @@ QString SelectHeaderTypeComboBox::code() const
     if (str.isEmpty()) {
         str = currentText();
         if (str == i18n(selectMultipleHeaders)) {
-            str = QString(); //return QString();
+            str = QString(); // return QString();
         }
     }
     if (!str.isEmpty() && !str.startsWith(QLatin1Char('['))) {
@@ -299,7 +293,7 @@ void SelectHeaderTypeComboBox::setCode(const QString &code)
             break;
         }
     }
-    //If not found select last combobox item
+    // If not found select last combobox item
     if (!foundHeaders) {
         if (code.startsWith(QLatin1Char('['))) {
             setCurrentIndex(count() - 1);
