@@ -1,27 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveincludewidget.h"
-#include "sievescriptblockwidget.h"
+#include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
-#include "autocreatescripts/autocreatescriptutil_p.h"
 #include "editor/sieveeditorutil.h"
+#include "sievescriptblockwidget.h"
 #include "widgets/includefilelineedit.h"
+#include <Libkdepim/LineEditCatchReturnKey>
 
-#include <QPushButton>
 #include <KLocalizedString>
 #include <QIcon>
+#include <QPushButton>
 
-#include <QGridLayout>
+#include "libksieve_debug.h"
 #include <QCheckBox>
+#include <QGridLayout>
 #include <QLabel>
 #include <QWhatsThis>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
@@ -90,8 +91,7 @@ void SieveIncludeActionWidget::loadScript(QXmlStreamReader &element, QString &er
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
-            if (tagValue == QLatin1String("personal")
-                || tagValue == QLatin1String("global")) {
+            if (tagValue == QLatin1String("personal") || tagValue == QLatin1String("global")) {
                 mLocation->setCode(AutoCreateScriptUtil::tagValue(tagValue), error);
             } else if (tagValue == QLatin1String("optional")) {
                 mOptional->setChecked(true);
@@ -130,25 +130,26 @@ void SieveIncludeActionWidget::initWidget()
     mLayout = new QGridLayout(this);
     mLayout->setContentsMargins({});
 
-    QLabel *lab = new QLabel(i18n("Include:"));
+    auto lab = new QLabel(i18n("Include:"), this);
     mLayout->addWidget(lab, 1, 0);
     mLocation = new SieveIncludeLocation(this);
     connect(mLocation, &SieveIncludeLocation::valueChanged, this, &SieveIncludeActionWidget::valueChanged);
     mLayout->addWidget(mLocation, 1, 1);
 
-    lab = new QLabel(i18n("Name:"));
+    lab = new QLabel(i18n("Name:"), this);
     mLayout->addWidget(lab, 1, 2);
 
     mIncludeFileName = new IncludeFileLineEdit(this);
+    new KPIM::LineEditCatchReturnKey(mIncludeFileName, this);
     mIncludeFileName->setClearButtonEnabled(true);
     connect(mIncludeFileName, &QLineEdit::textChanged, this, &SieveIncludeActionWidget::valueChanged);
     mLayout->addWidget(mIncludeFileName, 1, 3);
 
-    mOptional = new QCheckBox(i18n("Optional"));
+    mOptional = new QCheckBox(i18n("Optional"), this);
     connect(mOptional, &QCheckBox::toggled, this, &SieveIncludeActionWidget::valueChanged);
     mLayout->addWidget(mOptional, 1, 4);
 
-    mOnce = new QCheckBox(i18n("Once"));
+    mOnce = new QCheckBox(i18n("Once"), this);
     connect(mOnce, &QCheckBox::toggled, this, &SieveIncludeActionWidget::valueChanged);
     mLayout->addWidget(mOnce, 1, 5);
 
@@ -192,7 +193,7 @@ void SieveIncludeActionWidget::updateAddRemoveButton(bool addButtonEnabled, bool
 SieveIncludeWidget::SieveIncludeWidget(QWidget *parent)
     : SieveWidgetPageAbstract(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mHelpButton = new SieveHelpButton(this);
     lay->addWidget(mHelpButton);
     connect(mHelpButton, &SieveHelpButton::clicked, this, &SieveIncludeWidget::slotHelp);
@@ -215,7 +216,8 @@ void SieveIncludeWidget::setListOfIncludeFile(const QStringList &lst)
 void SieveIncludeWidget::slotHelp()
 {
     const QString help = i18n(
-        "The \"include\" command takes an optional \"location\" parameter, an optional \":once\" parameter, an optional \":optional\" parameter, and a single string argument representing the name of the script to include for processing at that point.");
+        "The \"include\" command takes an optional \"location\" parameter, an optional \":once\" parameter, an optional \":optional\" parameter, and a single "
+        "string argument representing the name of the script to include for processing at that point.");
     const QString href = QStringLiteral("https://tools.ietf.org/html/rfc6609#page-4");
     const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help, href);
     QWhatsThis::showText(QCursor::pos(), fullWhatsThis, mHelpButton);
@@ -223,7 +225,7 @@ void SieveIncludeWidget::slotHelp()
 
 void SieveIncludeWidget::generatedScript(QString &script, QStringList &requireModules, bool inForEveryPartLoop)
 {
-    Q_UNUSED(inForEveryPartLoop);
+    Q_UNUSED(inForEveryPartLoop)
     QString result;
     QStringList lst;
     mIncludeLister->generatedScript(result, lst);
@@ -280,7 +282,7 @@ void SieveIncludeWidgetLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled, removeButtonEnabled);
     }
 }
@@ -288,12 +290,12 @@ void SieveIncludeWidgetLister::updateAddRemoveButton()
 void SieveIncludeWidgetLister::setListOfIncludeFile(const QStringList &listOfIncludeFile)
 {
     mListOfIncludeFile = listOfIncludeFile;
-    //Update all lineedit
+    // Update all lineedit
     const QList<QWidget *> widgetList = widgets();
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
         w->setListOfIncludeFile(mListOfIncludeFile);
     }
 }
@@ -305,7 +307,7 @@ void SieveIncludeWidgetLister::generatedScript(QString &script, QStringList &req
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
+        auto w = qobject_cast<SieveIncludeActionWidget *>(*wIt);
         w->generatedScript(script);
     }
 }
@@ -320,7 +322,7 @@ void SieveIncludeWidgetLister::reconnectWidget(SieveIncludeActionWidget *w)
 void SieveIncludeWidgetLister::clearWidget(QWidget *aWidget)
 {
     if (aWidget) {
-        auto *widget = static_cast<SieveIncludeActionWidget *>(aWidget);
+        auto widget = static_cast<SieveIncludeActionWidget *>(aWidget);
         widget->clear();
     }
     Q_EMIT valueChanged();
@@ -328,7 +330,7 @@ void SieveIncludeWidgetLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveIncludeWidgetLister::createWidget(QWidget *parent)
 {
-    auto *w = new SieveIncludeActionWidget(parent);
+    auto w = new SieveIncludeActionWidget(parent);
     w->setListOfIncludeFile(mListOfIncludeFile);
     reconnectWidget(w);
     return w;
