@@ -1,26 +1,26 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptblockwidget.h"
+#include "autocreatescriptutil_p.h"
 #include "sieveactionwidgetlister.h"
 #include "sieveconditionwidgetlister.h"
-#include "autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
 #include <QComboBox>
-#include <QPushButton>
 #include <QIcon>
+#include <QPushButton>
 
-#include <QXmlStreamReader>
-#include <QVBoxLayout>
-#include <QGroupBox>
-#include <QButtonGroup>
-#include <QRadioButton>
-#include <QLabel>
 #include "libksieve_debug.h"
+#include <QButtonGroup>
+#include <QGroupBox>
+#include <QLabel>
+#include <QRadioButton>
+#include <QVBoxLayout>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
@@ -28,11 +28,11 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     : SieveWidgetPageAbstract(parent)
     , mSieveGraphicalModeWidget(graphicalModeWidget)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
 
-    mConditions = new QGroupBox(i18n("Conditions"));
-    auto *vbox = new QVBoxLayout;
+    mConditions = new QGroupBox(i18n("Conditions"), this);
+    auto vbox = new QVBoxLayout;
 
     mAllMessageRBtn = new QRadioButton(i18n("Match all messages"), this);
     mMatchAll = new QRadioButton(i18n("Match a&ll of the following"), this);
@@ -45,7 +45,7 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     mMatchAny->setChecked(false);
     mAllMessageRBtn->setChecked(false);
 
-    auto *bg = new QButtonGroup(this);
+    auto bg = new QButtonGroup(this);
     bg->addButton(mMatchAll);
     bg->addButton(mMatchAny);
     bg->addButton(mAllMessageRBtn);
@@ -59,7 +59,7 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
 
     topLayout->addWidget(mConditions, 0, Qt::AlignTop);
 
-    QGroupBox *actions = new QGroupBox(i18n("Actions"));
+    auto actions = new QGroupBox(i18n("Actions"), this);
     vbox = new QVBoxLayout;
     actions->setLayout(vbox);
     mScriptActionLister = new SieveActionWidgetLister(mSieveGraphicalModeWidget, this);
@@ -67,15 +67,15 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     vbox->addWidget(mScriptActionLister, 0, Qt::AlignTop);
     topLayout->addWidget(actions);
 
-    auto *newBlockLayout = new QHBoxLayout;
-    QLabel *lab = new QLabel(i18n("Add new block:"));
+    auto newBlockLayout = new QHBoxLayout;
+    auto lab = new QLabel(i18n("Add new block:"));
     newBlockLayout->addWidget(lab);
-    mNewBlockType = new QComboBox;
+    mNewBlockType = new QComboBox(this);
     newBlockLayout->addWidget(mNewBlockType);
     mNewBlockType->addItem(i18n("\"elsif\" block"));
     mNewBlockType->addItem(i18n("\"else\" block"));
 
-    mAddBlockType = new QPushButton;
+    mAddBlockType = new QPushButton(this);
     mAddBlockType->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mAddBlockType->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     newBlockLayout->addWidget(mAddBlockType);
@@ -167,7 +167,7 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
     bool onlyActions = false;
     if (mMatchCondition == AllCondition) {
         onlyActions = true;
-        //Just actions type
+        // Just actions type
     } else if (pageType() == BlockElse) {
         script += QLatin1String("else {\n");
     } else {
@@ -187,7 +187,7 @@ void SieveScriptBlockWidget::generatedScript(QString &script, QStringList &requi
         case BlockElse:
             break;
         default:
-            //We can got here.
+            // We can got here.
             break;
         }
 
