@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptpage.h"
-#include "sievescripttabwidget.h"
-#include "sieveincludewidget.h"
+#include "sieveeditorgraphicalmodewidget.h"
 #include "sieveforeverypartwidget.h"
 #include "sieveglobalvariablewidget.h"
-#include "sieveeditorgraphicalmodewidget.h"
+#include "sieveincludewidget.h"
+#include "sievescripttabwidget.h"
 
-#include "sievewidgetpageabstract.h"
 #include "autocreatescripts/autocreatescriptdialog.h"
+#include "sievewidgetpageabstract.h"
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -25,7 +25,7 @@ SieveScriptPage::SieveScriptPage(SieveEditorGraphicalModeWidget *sieveEditorGrap
     : QWidget(parent)
     , mSieveGraphicalModeWidget(sieveEditorGraphicalWidget)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
     mTabWidget = new SieveScriptTabWidget(this);
     connect(mTabWidget, &SieveScriptTabWidget::tabCloseRequested, this, &SieveScriptPage::slotCloseTab);
@@ -74,7 +74,7 @@ SieveScriptBlockWidget *SieveScriptPage::addScriptBlock(KSieveUi::SieveWidgetPag
 
 SieveScriptBlockWidget *SieveScriptPage::createScriptBlock(KSieveUi::SieveWidgetPageAbstract::PageType type)
 {
-    auto *blockWidget = new SieveScriptBlockWidget(mSieveGraphicalModeWidget);
+    auto blockWidget = new SieveScriptBlockWidget(mSieveGraphicalModeWidget);
     connect(blockWidget, &SieveScriptBlockWidget::addNewBlock, this, &SieveScriptPage::slotAddNewBlock);
     connect(blockWidget, &SieveScriptBlockWidget::valueChanged, this, &SieveScriptPage::valueChanged);
     blockWidget->setPageType(type);
@@ -99,7 +99,7 @@ void SieveScriptPage::slotAddNewBlock(QWidget *widget, KSieveUi::SieveWidgetPage
         return;
     }
     SieveScriptBlockWidget *blockWidget = createScriptBlock(type);
-    if (type == KSieveUi::SieveScriptBlockWidget::BlockElse) { //Insert at the end of tabwidget
+    if (type == KSieveUi::SieveScriptBlockWidget::BlockElse) { // Insert at the end of tabwidget
         mTabWidget->insertTab(mTabWidget->count(), blockWidget, blockName(type));
     } else {
         mTabWidget->insertTab(mTabWidget->indexOf(widget) + 1, blockWidget, blockName(type));
@@ -137,7 +137,7 @@ void SieveScriptPage::generatedScript(QString &script, QStringList &required)
     }
     const int numberOfTab(mTabWidget->count());
     for (int i = 0; i < numberOfTab; ++i) {
-        auto *page = static_cast<SieveWidgetPageAbstract *>(mTabWidget->widget(i));
+        auto page = static_cast<SieveWidgetPageAbstract *>(mTabWidget->widget(i));
         if (page->pageType() != KSieveUi::SieveScriptBlockWidget::ForEveryPart) {
             page->generatedScript(script, required, inForEveryPartLoop);
         }
