@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,22 +9,16 @@
 
 #include <QWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveWidgetPageAbstract : public QWidget
 {
     Q_OBJECT
 public:
-    enum PageType {
-        BlockIf = 0,
-        BlockElsIf = 1,
-        BlockElse = 2,
-        Include = 3,
-        ForEveryPart = 4,
-        GlobalVariable = 5
-    };
+    enum PageType { BlockIf = 0, BlockElsIf = 1, BlockElse = 2, Include = 3, ForEveryPart = 4, GlobalVariable = 5 };
 
     explicit SieveWidgetPageAbstract(QWidget *parent = nullptr);
-    ~SieveWidgetPageAbstract();
+    ~SieveWidgetPageAbstract() override;
 
     virtual void generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop) = 0;
 
