@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -15,7 +15,7 @@ class SieveInfoDialogTest : public QObject
     Q_OBJECT
 public:
     explicit SieveInfoDialogTest(QObject *parent = nullptr);
-    ~SieveInfoDialogTest() = default;
+    ~SieveInfoDialogTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
