@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,47 +8,46 @@
 #include "sieveeditorwidget.h"
 #include "sievepurposemenuwidget.h"
 
-#include "sieve-editor.h"
-#include "sieveeditortextmodewidget.h"
-#include "scriptsparsing/parsingutil.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/sievescriptparsingerrordialog.h"
-#include "sieveeditormenubar.h"
 #include "editor/sieveinfodialog.h"
+#include "scriptsparsing/parsingutil.h"
+#include "sieve-editor.h"
+#include "sieveeditormenubar.h"
+#include "sieveeditortextmodewidget.h"
 
-#include <kns3/uploaddialog.h>
-#include <KLocalizedString>
-#include <KIconLoader>
-#include <QTemporaryDir>
-#include <kzip.h>
-#include <KIconEngine>
-#include <KStandardAction>
 #include <KActionMenu>
+#include <KIconEngine>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KStandardAction>
+#include <QTemporaryDir>
+#include <kns3/uploaddialog.h>
+#include <kzip.h>
 
 #include <PimCommon/PurposeMenuWidget>
 
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QStackedWidget>
-#include <QLabel>
-#include <QLineEdit>
-#include <QToolBar>
 #include "libksieve_debug.h"
 #include <QAction>
+#include <QLabel>
+#include <QLineEdit>
 #include <QPointer>
+#include <QPushButton>
+#include <QStackedWidget>
 #include <QStandardPaths>
-#include <QDir>
 #include <QTemporaryFile>
+#include <QToolBar>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
 SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
-    auto *toolbar = new QToolBar;
+    auto toolbar = new QToolBar;
     toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
@@ -66,7 +65,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     connect(mSwitchMode, &QAction::triggered, this, &SieveEditorWidget::slotSwitchMode);
 
     if (mDebug) {
-        //Not necessary to translate it.
+        // Not necessary to translate it.
         mGenerateXml = new QAction(QStringLiteral("Generate xml"), this);
         connect(mGenerateXml, &QAction::triggered, this, &SieveEditorWidget::slotGenerateXml);
         toolbar->addAction(mGenerateXml);
@@ -76,13 +75,13 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     overlays << QStringLiteral("list-add");
     mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share Script..."), this);
     connect(mShareScript, &QAction::triggered, this, &SieveEditorWidget::slotShareScript);
-    //Add action to toolBar
+    // Add action to toolBar
 
     toolbar->addAction(mShareScript);
 
-    auto *purposeMenu = new SievePurposeMenuWidget(this, this);
-    KActionMenu *shareAction = new KActionMenu(i18n("Share..."), this);
-    shareAction->setDelayed(false);
+    auto purposeMenu = new SievePurposeMenuWidget(this, this);
+    auto shareAction = new KActionMenu(i18n("Share..."), this);
+    shareAction->setPopupMode(QToolButton::InstantPopup);
     shareAction->setMenu(purposeMenu->menu());
     shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(this);
@@ -132,10 +131,10 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     lay->addWidget(toolbar);
 
-    auto *nameLayout = new QHBoxLayout;
-    QLabel *label = new QLabel(i18n("Script name:"));
+    auto nameLayout = new QHBoxLayout;
+    auto label = new QLabel(i18n("Script name:"), this);
     nameLayout->addWidget(label);
-    mScriptName = new QLineEdit;
+    mScriptName = new QLineEdit(this);
     mScriptName->setReadOnly(true);
     nameLayout->addWidget(mScriptName);
     lay->addLayout(nameLayout);
@@ -255,8 +254,7 @@ void SieveEditorWidget::updateOriginalScript()
 void SieveEditorWidget::print()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool wasModified = isModified();
         mTextModeWidget->print();
         setModified(wasModified);
@@ -273,8 +271,7 @@ void SieveEditorWidget::print()
 void SieveEditorWidget::printPreview()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool wasModified = isModified();
         mTextModeWidget->printPreview();
         setModified(wasModified);
@@ -387,7 +384,9 @@ void SieveEditorWidget::slotShareScript()
     QTemporaryFile tmpFile;
     if (tmpFile.open()) {
         QTextStream out(&tmpFile);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         out.setCodec("UTF-8");
+#endif
         out << script();
         tmpFile.close();
         const QString sourceName = mScriptName->text();
@@ -475,7 +474,7 @@ QString SieveEditorWidget::originalScript() const
 void SieveEditorWidget::setScript(const QString &script, bool clearUndoRedo)
 {
     mTextModeWidget->setScript(script, clearUndoRedo);
-    //Necessary to take text from editor otherwise script has \r\n
+    // Necessary to take text from editor otherwise script has \r\n
     mOriginalScript = mTextModeWidget->script();
 }
 
@@ -498,8 +497,7 @@ void SieveEditorWidget::addMessageEntry(const QString &errorMsg, const QColor &c
 {
     QString msg = errorMsg;
     msg.replace(QLatin1Char('\n'), QStringLiteral("<br>"));
-    const QString logText = QStringLiteral("<font color=%1>%2</font>")
-                            .arg(color.name(), msg);
+    const QString logText = QStringLiteral("<font color=%1>%2</font>").arg(color.name(), msg);
 
     setDebugScript(logText);
 }
@@ -625,8 +623,7 @@ void SieveEditorWidget::slotSwitchToGraphicalMode()
 void SieveEditorWidget::slotSwitchMode()
 {
     switch (mMode) {
-    case TextMode:
-    {
+    case TextMode: {
         bool result = false;
         const QString doc = ParsingUtil::parseScript(mTextModeWidget->currentscript(), result);
         if (result) {
@@ -645,8 +642,7 @@ void SieveEditorWidget::slotSwitchMode()
         }
         break;
     }
-    case GraphicMode:
-    {
+    case GraphicMode: {
         const QString script = mGraphicalModeWidget->currentscript();
         changeMode(TextMode);
         mTextModeWidget->setScript(script);
