@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define SIEVEPURPOSEMENUWIDGET_H
 
 #include <PimCommon/PurposeMenuWidget>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorWidget;
 class SievePurposeMenuWidget : public PimCommon::PurposeMenuWidget
 {
@@ -19,6 +20,7 @@ public:
 
     Q_REQUIRED_RESULT QByteArray text() override;
     void setEditorWidget(SieveEditorWidget *editor);
+
 private:
     SieveEditorWidget *mSieveEditorWidget = nullptr;
 };
