@@ -1,31 +1,23 @@
 /*
-  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef SIEVETEXTEDITWIDGET_H
 #define SIEVETEXTEDITWIDGET_H
 
-#include <QWidget>
 #include "ksieveui_private_export.h"
-namespace KPIMTextEdit {
+#include <QWidget>
+#include <memory>
+namespace KPIMTextEdit
+{
 class SlideContainer;
 class PlainTextEditFindBar;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEdit;
 class SieveTextEditWidgetPrivate;
 class KSIEVEUI_TESTS_EXPORT SieveTextEditWidget : public QWidget
@@ -34,7 +26,7 @@ class KSIEVEUI_TESTS_EXPORT SieveTextEditWidget : public QWidget
 public:
     explicit SieveTextEditWidget(QWidget *parent = nullptr);
     SieveTextEditWidget(KSieveUi::SieveTextEdit *customTextEdit, QWidget *parent);
-    ~SieveTextEditWidget();
+    ~SieveTextEditWidget() override;
     void setReadOnly(bool readOnly);
 
     Q_REQUIRED_RESULT KSieveUi::SieveTextEdit *textEdit() const;
@@ -45,7 +37,7 @@ public Q_SLOTS:
 
 private:
     void initialize(KSieveUi::SieveTextEdit *custom = nullptr);
-    SieveTextEditWidgetPrivate *const d;
+    std::unique_ptr<SieveTextEditWidgetPrivate> const d;
     KSieveUi::SieveTextEdit *mTextEdit = nullptr;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
     KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
