@@ -1,25 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef SIEVEEDITORPARSINGMISSINGFEATUREWARNING_H
 #define SIEVEEDITORPARSINGMISSINGFEATUREWARNING_H
 
-#include <KMessageWidget>
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <KMessageWidget>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT SieveEditorParsingMissingFeatureWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
-    enum TextEditorType {
-        TextEditor,
-        GraphicEditor
-    };
+    enum TextEditorType { TextEditor, GraphicEditor };
 
     explicit SieveEditorParsingMissingFeatureWarning(SieveEditorParsingMissingFeatureWarning::TextEditorType type, QWidget *parent = nullptr);
-    ~SieveEditorParsingMissingFeatureWarning();
+    ~SieveEditorParsingMissingFeatureWarning() override;
 
     void setErrors(const QString &initialScript, const QString &errors);
     Q_REQUIRED_RESULT QString initialScript() const;
