@@ -1,5 +1,5 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,29 +7,28 @@
 #include "findbarbase.h"
 #include <PimCommon/LineEditWithCompleterNg>
 
-#include <QIcon>
-#include <KLocalizedString>
-#include <KLineEdit>
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <QIcon>
 
+#include <QEvent>
 #include <QHBoxLayout>
-#include <QPushButton>
-#include <QTimer>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QMenu>
+#include <QPushButton>
+#include <QTimer>
 #include <QToolButton>
-#include <QEvent>
-#include <QKeyEvent>
 
 using namespace KSieveUi;
 
 FindBarBase::FindBarBase(QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->setContentsMargins(2, 2, 2, 2);
 
-    auto *closeBtn = new QToolButton(this);
+    auto closeBtn = new QToolButton(this);
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setObjectName(QStringLiteral("close"));
     closeBtn->setIconSize(QSize(16, 16));
@@ -42,7 +41,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     closeBtn->setAutoRaise(true);
     lay->addWidget(closeBtn);
 
-    QLabel *label = new QLabel(i18nc("Find text", "F&ind:"), this);
+    auto label = new QLabel(i18nc("Find text", "F&ind:"), this);
     lay->addWidget(label);
 
     mSearch = new PimCommon::LineEditWithCompleterNg(this);
@@ -64,7 +63,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     lay->addWidget(mFindPrevBtn);
     mFindPrevBtn->setEnabled(false);
 
-    auto *optionsBtn = new QPushButton(this);
+    auto optionsBtn = new QPushButton(this);
     optionsBtn->setText(i18n("Options"));
     optionsBtn->setToolTip(i18n("Modify search behavior"));
     mOptionsMenu = new QMenu(optionsBtn);
@@ -89,7 +88,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     lay->addWidget(mStatus);
 
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
-    //lay->addStretch();
+    // lay->addStretch();
     hide();
 }
 
@@ -165,8 +164,8 @@ void FindBarBase::setFoundMatch(bool match)
 
 void FindBarBase::searchText(bool backward, bool isAutoSearch)
 {
-    Q_UNUSED(backward);
-    Q_UNUSED(isAutoSearch);
+    Q_UNUSED(backward)
+    Q_UNUSED(isAutoSearch)
 }
 
 void FindBarBase::addToCompletion(const QString &text)
@@ -226,7 +225,7 @@ bool FindBarBase::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             if (shortCutOverride) {
                 e->accept();
@@ -235,8 +234,7 @@ bool FindBarBase::event(QEvent *e)
             e->accept();
             closeBar();
             return true;
-        } else if (kev->key() == Qt::Key_Enter
-                   || kev->key() == Qt::Key_Return) {
+        } else if (kev->key() == Qt::Key_Enter || kev->key() == Qt::Key_Return) {
             e->accept();
             if (shortCutOverride) {
                 return true;
