@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,14 +7,16 @@
 #define SIEVEEDITORHELPHTMLWIDGET_H
 
 #include "ksieveui_export.h"
-#include <QWidget>
 #include <QUrl>
+#include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class SlideContainer;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorWebEngineView;
 class SieveEditorLoadProgressIndicator;
 class FindBarWebEngineView;
@@ -23,7 +25,7 @@ class KSIEVEUI_EXPORT SieveEditorHelpHtmlWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveEditorHelpHtmlWidget(QWidget *parent = nullptr);
-    ~SieveEditorHelpHtmlWidget();
+    ~SieveEditorHelpHtmlWidget() override;
 
     void openUrl(const QUrl &currentUrl);
     Q_REQUIRED_RESULT QString title() const;
