@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -10,22 +10,26 @@
 #include <QObject>
 #include <QStringList>
 #include <QUrl>
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class GenerateGlobalScriptJob : public QObject
 {
     Q_OBJECT
 public:
     explicit GenerateGlobalScriptJob(const QUrl &url, QObject *parent = nullptr);
-    ~GenerateGlobalScriptJob();
+    ~GenerateGlobalScriptJob() override;
 
     void start();
     void kill();
 
     void addUserActiveScripts(const QStringList &lstScript);
 
+    void setForceActivateUserScript(bool f);
+
 Q_SIGNALS:
     void success();
     void error(const QString &msgError);
@@ -39,6 +43,7 @@ private:
     void writeUserScript();
     QStringList mListUserActiveScripts;
     const QUrl mCurrentUrl;
+    bool mForceActivateUserScript = false;
     KManageSieve::SieveJob *mMasterJob = nullptr;
     KManageSieve::SieveJob *mUserJob = nullptr;
 };
