@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptdebuggerwidgettest.h"
 #include "../sievescriptdebuggerwidget.h"
-#include <QTest>
 #include <QStackedWidget>
+#include <QTest>
 
 SieveScriptDebuggerWidgetTest::SieveScriptDebuggerWidgetTest(QObject *parent)
     : QObject(parent)
@@ -21,7 +21,7 @@ SieveScriptDebuggerWidgetTest::~SieveScriptDebuggerWidgetTest()
 void SieveScriptDebuggerWidgetTest::shouldHaveDefaultValue()
 {
     KSieveUi::SieveScriptDebuggerWidget w;
-    auto *stackedwidget = w.findChild<QStackedWidget *>(QStringLiteral("stackedwidget"));
+    auto stackedwidget = w.findChild<QStackedWidget *>(QStringLiteral("stackedwidget"));
     QVERIFY(stackedwidget);
 
     const int numberOfStackWidget(2);
