@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,17 +7,19 @@
 #ifndef SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
 #define SIEVESCRIPTDEBUGGERFRONTENDWIDGET_H
 
-#include <QWidget>
 #include "ksieveui_private_export.h"
+#include <QWidget>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 class KUrlRequester;
 class QProcess;
 class QLineEdit;
 class QSplitter;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEditWidget;
 class SieveScriptDebuggerWarning;
 class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
@@ -25,7 +27,7 @@ class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerFrontEndWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerFrontEndWidget(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerFrontEndWidget();
+    ~SieveScriptDebuggerFrontEndWidget() override;
 
     Q_REQUIRED_RESULT QString script() const;
     void setScript(const QString &script);
