@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <editor/sievetextedit.h>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptDebuggerTextEdit : public KSieveUi::SieveTextEdit
 {
     Q_OBJECT
