@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -10,17 +10,19 @@
 #include <QUrl>
 
 #include <QObject>
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class VacationHelperJob : public QObject
 {
     Q_OBJECT
 public:
     explicit VacationHelperJob(const QUrl &url, QObject *parent = nullptr);
-    ~VacationHelperJob();
+    ~VacationHelperJob() override;
 
     void searchActiveJob();
 
