@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,16 @@
 #ifndef VACATIONMAILLINEEDIT_H
 #define VACATIONMAILLINEEDIT_H
 
-#include <QLineEdit>
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <QLineEdit>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT VacationMailLineEdit : public QLineEdit
 {
     Q_OBJECT
 public:
     explicit VacationMailLineEdit(QWidget *parent = nullptr);
-    ~VacationMailLineEdit() = default;
+    ~VacationMailLineEdit() override = default;
 
     void setInvalidEmail(bool state);
 };
